@@ -17,9 +17,7 @@ func TestVCSLookup(t *testing.T) {
 	}{
 		"https://github.com/masterminds":                                   {work: false, t: Git},
 		"https://github.com/Masterminds/VCSTestRepo":                       {work: true, t: Git},
-		"https://bitbucket.org/mattfarina/testhgrepo":                      {work: true, t: Hg},
-		"https://bitbucket.org/mattfarina/repo-does-not-exist":             {work: false, t: Hg},
-		"https://bitbucket.org/mattfarina/private-repo-for-vcs-testing":    {work: false, t: Hg},
+		"https://bitbucket.org/mattfarina/atest":                           {work: true, t: Git},
 		"https://launchpad.net/govcstestbzrrepo/trunk":                     {work: true, t: Bzr},
 		"https://launchpad.net/~mattfarina/+junk/mygovcstestbzrrepo":       {work: true, t: Bzr},
 		"https://launchpad.net/~mattfarina/+junk/mygovcstestbzrrepo/trunk": {work: true, t: Bzr},
@@ -34,11 +32,10 @@ func TestVCSLookup(t *testing.T) {
 		"https://example.com/foo/bar/baz.hg":                               {work: true, t: Hg},
 		"https://gopkg.in/tomb.v1":                                         {work: true, t: Git},
 		"https://golang.org/x/net":                                         {work: true, t: Git},
-		"https://speter.net/go/exp/math/dec/inf":                           {work: true, t: Git},
 		"https://git.openstack.org/foo/bar":                                {work: true, t: Git},
 		"git@github.com:Masterminds/vcs.git":                               {work: true, t: Git},
 		"git@example.com:foo.git":                                          {work: true, t: Git},
-		"ssh://hg@bitbucket.org/mattfarina/testhgrepo":                     {work: true, t: Hg},
+		"ssh://bitbucket.org/mattfarina/testhgrepo":                        {work: true, t: Git},
 		"git@bitbucket.org:mattfarina/glide-bitbucket-example.git":         {work: true, t: Git},
 		"git+ssh://example.com/foo/bar":                                    {work: true, t: Git},
 		"git://example.com/foo/bar":                                        {work: true, t: Git},
@@ -46,6 +43,9 @@ func TestVCSLookup(t *testing.T) {
 		"svn+ssh://example.com/foo/bar":                                    {work: true, t: Svn},
 		"git@example.com:foo/bar":                                          {work: true, t: Git},
 		"hg@example.com:foo/bar":                                           {work: true, t: Hg},
+		"http://hg.code.sf.net/p/masterminds/test":                         {work: true, t: Hg},
+		"http://git.code.sf.net/p/masterminds/test":                        {work: true, t: Git},
+		"http://svn.code.sf.net/p/masterminds/test":                        {work: true, t: Svn},
 	}
 
 	for u, c := range urlList {
@@ -111,27 +111,3 @@ func TestVCSFileLookup(t *testing.T) {
 		t.Errorf("Detected wrong type from file:// path. Found type %v", ty)
 	}
 }
-
-func TestNotFound(t *testing.T) {
-	_, _, err := detectVcsFromRemote("https://mattfarina.com/notfound")
-	if err == nil || !strings.HasSuffix(err.Error(), " Not Found") {
-		t.Errorf("Failed to find not found repo")
-	}
-
-	_, err = NewRepo("https://mattfarina.com/notfound", "")
-	if err == nil || !strings.HasSuffix(err.Error(), " Not Found") {
-		t.Errorf("Failed to find not found repo")
-	}
-}
-
-func TestAccessDenied(t *testing.T) {
-	_, _, err := detectVcsFromRemote("https://bitbucket.org/mattfarina/private-repo-for-vcs-testing")
-	if err == nil || err.Error() != "Access Denied" {
-		t.Errorf("Failed to detect access denied")
-	}
-
-	_, err = NewRepo("https://bitbucket.org/mattfarina/private-repo-for-vcs-testing", "")
-	if err == nil || err.Error() != "Access Denied" {
-		t.Errorf("Failed to detect access denied")
-	}
-}
